<?php
/**
 * @copyright
 */

defined('_JEXEC') or die;

/**
 * Class SefAdvanceHelper
 */
abstract class SefAdvanceHelper
{
	/**
	 * Returns the mapped alias for a key name.
	 *
	 * @param string $key     The name of the key.
	 * @param bool   $reverse True if reverse the map search (from alias to original).
	 *
	 * @return string The mapped alias if exists, or the original otherwise.
	 */
	public static function getMappedString($key, $reverse = false)
{
	$map = SefAdvanceConfig::get('custom_comp');

	// Switch keys and values for the reverse search
	if ($reverse)
	{
		$map = array_flip($map);
	}

	return isset($map[$key]) ? $map[$key] : $key;
}

	/**
	 * Retrieve the slug for a purpose element.
	 *
	 * @param int $id The ID of the purpose to retrieve.
	 *
	 * @return mixed
	 */
	public static function getPurposeSlug($id)
{
	$db = JFactory::getDbo();

	$query = $db
		->getQuery(true)
		->select('slug')
		->from('#__unprefixedName___purposes')
		->where('__unprefixedName___purpose_id = ' . $db->quote($id));

	return $db
		->setQuery($query)
		->loadResult();
}

	/**
	 * Retrieve the menu ItemID for a page.
	 *
	 * @param string $view   The view of the page.
	 * @param string $layout The layout of the page.
	 *
	 * @return mixed
	 */
	public static function findMenuItem($view, $layout = '')
{
	$db = JFactory::getDbo();

	// Build the query to get the menu item
	$query = $db
		->getQuery(true)
		->select('id')
		->from('#__menu')
		->where('link LIKE "%option=__name__%"');

	// Filter by view if present
	$query->where("link LIKE '%view=$view%'");

	// Filter by layout if present
	if (!empty($layout))
	{
		$query->where("link LIKE '%layout=$layout%'");
	}

	// Get the Itemid
	return $db
		->setQuery($query)
		->loadResult();
}
}