<?php
/**
 * @copyright
 */

defined('_JEXEC') or die;

/**
 * Returns the mapped alias for a key name.
 *
 * @param string $key     The name of the key.
 * @param bool   $reverse True if reverse the map search (from alias to original).
 *
 * @return string The mapped alias if exists, or the original otherwise.
 */
function getMappedKey($key, $reverse = false)
{
	$map = array(
		'authors'       => 'autori',
		'author'        => 'autore',
		'designers'     => 'progettisti',
		'designer'      => 'progettista',
		'advertisement' => 'pubblicita',
		'projects'      => 'progetti',
		'project'       => 'progetto',
		'write'         => 'proponiti',
		'error'         => 'errore',
		'sent'          => 'inviata',
		'about'         => 'redazione'
	);

	// Switch keys and values for the reverse search
	if ($reverse)
	{
		$map = array_flip($map);
	}

	return isset($map[$key]) ? $map[$key] : $key;
}

/**
 * @param $query
 *
 * @return array
 */
function __nameCamelcase__BuildRoute(&$query)
{
	$segments = array();

	// Parse view
	$segments[0] = getMappedKey($query['view']);

	// Parse layout
	if (isset($query['layout']))
	{
		$segments[1] = getMappedKey($query['layout']);
	};

	// If the view is known, we want to use only the descriptive part of the ID parameter, else pass over.
	if (in_array($query['view'], array('authors', 'designers', 'projects')) && isset($query['id']))
	{
		/* Explode the id query parameters, the first part is the numeric identifier, the second part is the alias
		of the element. Separated by semi column. */
		list($id_I, $alias_S) = explode(':', $query['id']);

		/* If the alias part is not present, retrieve it from the database, basing the match on the numeric part of
		the passed ID parameter. */
		if (!isset($alias_S))
		{
			$db = JFactory::getDbo();

			// Build the correct query based on the view name
			$db_query = $db
				->getQuery(true)
				->select('slug')
				->from('#__unprefixedName___' . $query['view'] . 's')
				->where('__unprefixedName___' . $query['view'] . '_id = ' . $db->quote($id_I));

			// Get the result
			$alias_S = $db
				->setQuery($db_query)
				->loadResult();
		}

		// Add the keyword-rich part in the SEF URL
		$segments[1] = $alias_S;

		// Remove the singular view from segments, will be traced in the Parse
//		$segments[0] = null;
	}

	// Unset parsed parts
	unset($query['view']);
	unset($query['id']);
	unset($query['layout']);

	// Link singular views to plural ones

	return $segments;
}

/**
 * @param $segments
 *
 * @return array
 */
function __nameCamelcase__ParseRoute($segments)
{
	$vars = array();

	// Parse view
	$vars['view'] = getMappedKey($segments[0], true);

	// Parse id or layout
	if (in_array($vars['view'], array('author', 'designer', 'project')) && isset($segments[1]))
	{
		$db = JFactory::getDbo();

		// Replace Joomla automatic semi column
		$segments[1] = preg_replace('/:/', '-', $segments[1], 1);

		// Build the query to retrieve the ID from the alias
		$query = $db
			->getQuery(true)
			->select('__unprefixedName___' . $vars['view'] . '_id')
			->from('#__unprefixedName___' . $vars['view'] . 's')
			->where('slug = ' . $db->quote($segments[1]));

		// Get the result
		$vars['id'] = $db
			->setQuery($query)
			->loadResult();
	}
	elseif (isset($segments[1]))
	{
		$vars['layout'] = getMappedKey($segments[1], true);
	}

	return $vars;
}