<?php
/**
 * @copyright
 */

defined('_JEXEC') or die;

/**
 * Class sef__unprefixedName__
 */
class sef__unprefixedName__
{
	protected $layouts = array('foo', 'bar');

	/**
	 * Create the pure-logic SEF URL for this component.
	 *
	 * @param string $string The original non-SEF URL.
	 *
	 * @return string The converted SEF URL.
	 */
	public function create($string)
	{
		$SEF_STRING = '';

		// Split the URL in his parts
		$url_A = parse_url($string);

		// Split the query parameters in an array
		parse_str(html_entity_decode($url_A['query']), $query_A);

		// Add the view part, always present
		$SEF_STRING .= SefAdvanceHelper::getMappedString($query_A['view']) . '/';

		// Add the layout part
		if (isset($query_A['layout']))
		{
			$SEF_STRING .= SefAdvanceHelper::getMappedString($query_A['layout']) . '/';
		}

		// Add the id part
		if (isset($query_A['id']))
		{
			// If the view is known, we want to use only the descriptive part of the ID parameter, else use all it.
			if (in_array($query_A['view'], array('authors', 'designers', 'projects')))
			{
				/* Explode the id query parameters, the first part is the numeric identifier, the second part is the alias
				of the element. Separated by semi column. */
				list($id_I, $alias_S) = explode(':', $query_A['id']);

				/* If the alias part is not present, retrieve it from the database, basing the match on the numeric part of
				the passed ID parameter. */
				if (!isset($alias_S))
				{
					$db   = JFactory::getDbo();
					$view = substr($query_A['view'], 0, -1); // to singular

					// Build the correct query based on the view name
					$query = $db
						->getQuery(true)
						->select('slug')
						->from('#__unprefixedName___' . $view . 's')
						->where('__unprefixedName___' . $view . '_id = ' . $db->quote($id_I));

					// Get the result
					$alias_S = $db
						->setQuery($query)
						->loadResult();
				}
			}
			else
			{
				$alias_S = $query_A['id'];
			}

			// Add the keyword-rich part in the SEF URL
			$SEF_STRING .= $alias_S . '/';
		}

		// Add __unprefixedName___purpose_id part
//		if (isset($query_A['__unprefixedName___purpose_id']))
//		{
//			list($id_S, $alias_S) = explode(':', $query_A['__unprefixedName___purpose_id']);
//
//			// If alias is not present retrive from database
//			if (!isset($alias_S))
//			{
//				$alias_S = __nameCamelcase__SlugHelper::getPurposeSlug($id_S);
//			}
//
//			$SEF_STRING .= 'f_' . $alias_S . '/';
//			unset($query_A['__unprefixedName___purpose_id']);
//		}

		// Unset the option and view parts
		unset($query_A['option']);
		unset($query_A['view']);
		unset($query_A['layout']);
		unset($query_A['id']);
		unset($query_A['Itemid']);
		unset($query_A['q']);

		// Add the Itemid part
//		if (isset($query_A['Itemid']))
//		{
//			unset($query_A['Itemid']);
//		}

		// Remove the trailing slash if there is a remaining query or there is a fragment
		if (count($query_A) || isset($url_A['fragment']))
		{
			$SEF_STRING = substr($SEF_STRING, 0, -1);
		}

		// Add the remaining unparsed query parameters
		if (count($query_A))
		{
			$SEF_STRING .= '?' . http_build_query($query_A);
		}

		// Add the anchors
		if (isset($url_A['fragment']))
		{
			$SEF_STRING .= '#' . $url_A['fragment'];
		}

		return $SEF_STRING;
	}

	/**
	 * @param $url_array
	 * @param $pos
	 *
	 * @return string
	 */
	public function revert($url_array, $pos)
	{
		$QUERY_STRING = '';

		// Remove unnecessary URL parts
		for ($i = 0; $i < $pos + 2; $i++)
		{
			array_shift($url_array);
		}

		// Revert the first segment (view)
		if (isset($url_array[0]))
		{
			$_GET['view'] = $_REQUEST['view'] = SefAdvanceHelper::getMappedString($url_array[0], true);
			$QUERY_STRING .= '&view=' . $_GET['view'];
		}

		// Revert the second segment (id or layout)
		if (isset($url_array[1]))
		{
			$mapped_name = SefAdvanceHelper::getMappedString($url_array[1], true);

			// Check if the segments is a layout
			if (in_array($mapped_name, $this->layouts))
			{
				$_GET['layout'] = $_REQUEST['layout'] = $mapped_name;
				$QUERY_STRING .= '&layout=' . $_GET['layout'];
			}
			else
			{
				// Deduce which type is the the segment (id or layout) based on the view name
				if (in_array($_GET['view'], array('authors', 'designers', 'projects')))
				{
					$db   = JFactory::getDbo();
					$view = substr($_GET['view'], 0, -1);

					// Build the query to retrieve the ID from the alias
					$query = $db
						->getQuery(true)
						->select('__unprefixedName___' . $view . '_id')
						->from('#__unprefixedName___' . $view . 's')
						->where('slug = ' . $db->quote($url_array[1]));

					// Get the result
					$id_I = $db
						->setQuery($query)
						->loadResult();
				}
				else
				{
					$id_I = $url_array[1];
				}

				$_GET['id'] = $_REQUEST['id'] = $id_I;
				$QUERY_STRING .= '&id=' . $id_I;
			}
		}

		// Find the proper Itemid
		$_GET['Itemid'] = $_REQUEST['Itemid'] = SefAdvanceHelper::findMenuItem($_GET['view'], $_GET['layout']);

		return $QUERY_STRING;
	}

}